#! -*- coding: utf-8 -*-
import json
import logging
import datetime
from decimal import Decimal

from bson import json_util

from django.template import RequestContext
from django.conf import settings
from django.http import HttpResponse
from django.shortcuts import render_to_response
from django.views.decorators.csrf import csrf_exempt

from acomea.soap.models import AcomeaClientCms
from acomea.fondi.models import Fund

log = logging.getLogger("acomea.vistesoap")
if not settings.VISTESOAP_FAKE_DATA:
    acomea_client = AcomeaClientCms()


def get_fondi_per_tipo(request):
    data = acomea_client.get_fondi_per_tipo(cod_tipo=request.POST['cod-tipo'])
    return HttpResponse("ok")

@csrf_exempt
def get_last_data_quote(request):
    if request.session.get("acomea_vistesoap_quote_date", None):
        return HttpResponse(request.session["acomea_vistesoap_quote_date"])
    try:
        data = acomea_client.get_last_data_quote() or None
    except Exception, e:
        data = None
        log.error("Exc in get_last_data_quote : %s" % str(e))
    return HttpResponse(
        "%s/%s/%s" % (data.day, data.month, data.year) if data else None
    )

@csrf_exempt
def save_quote_date_filter(request):
    request.session["acomea_vistesoap_quote_date"] = request.GET.get("data", None)
    return HttpResponse()

@csrf_exempt
def get_valori_riga_tabella_quote(request):
    json_data = None
    start_date = datetime.date.today().strftime("%d/%m/%Y")
    if 'data' in request.GET.keys():
        start_date = request.GET['data']
    try:
        data = acomea_client.get_valori_riga_tabella_quote(
            cod_fondo=request.GET['codfondo'],
            classe=request.GET['classe'],
            data=start_date
        )
        json_data = json.dumps(data, default=json_util.default)
    except Exception, e:
        log.error("Exc in get_valori_riga_tabella_quote : %s" % str(e))
    return HttpResponse(json_data)

GRAPH_DATASET_PIE = {
    'chart': {
        'renderTo': 'container-pie',
        'type': 'pie'
    },
    'title': {
        'text': None
    },
    'subtitle': {
        'text': None
    },
    'xAxis': {
        'categories': None
    },
    'yAxis': {
        'min': 0,
        'title': {
            'text': 'Valore',
            'align': 'high'
        },
        'labels': {
            'overflow': 'justify'
        }
    },

    'plotOptions': {
        'bar': {
            'dataLabels': {
                'enabled': True
            }
        }
    },
    'legend': {
        'layout': 'vertical',
        'align': 'right',
        'verticalAlign': 'top',
        'x': 0,
        'y': 0,
        'floating': True,
        'borderWidth': 1,
        'backgroundColor': '#FFFFFF',
        'shadow': True
    },
    'credits': {
        'enabled': False
    },
    'series' : [{
                    'name': 'fondo',
                    'data': None,
                    'color': '#F15A22'
                }]
}


GRAPH_DATASET_BAR = {
    'chart': {
        'renderTo': 'container-bar',
        'type': 'bar'
    },
    'title': {
        'text': None
    },
    'subtitle': {
        'text': None
    },
    'xAxis': {
        'categories': None
    },
    'yAxis': {
        'min': 0,
        'title': {
            'text': 'Valore',
            'align': 'high'
        },
        'labels': {
            'overflow': 'justify'
        }
    },

    'plotOptions': {
        'bar': {
            'dataLabels': {
                'enabled': True
            }
        }
    },
    'legend': {
        'layout': 'vertical',
        'align': 'right',
        'verticalAlign': 'top',
        'x': 0,
        'y': 0,
        'floating': True,
        'borderWidth': 1,
        'backgroundColor': '#FFFFFF',
        'shadow': True
    },
    'credits': {
        'enabled': False
    },
    'series' : [{
        'name': 'fondo',
        'data': None,
        'color': '#F15A22'
    }]
}

GRAPH_DATASET_LINE = {
    'chart' : {
        'renderTo' : 'container-line',
        'type' : 'line'
    },
    'title': {
        'text': None
    },
    'xAxis' : {
        'type' : 'datetime'
    },
    'yAxis' : {
        'title': {
            'text': 'Valore',
            'align': 'high'
        },
        'labels': {
            'overflow': 'justify'
        }
    },
    'series' : []
}

@csrf_exempt
def get_aree_geografiche(request):
    try:
        if settings.VISTESOAP_FAKE_DATA:
            import datetime
            data = {
                'DataAggiornamento': datetime.datetime(2013, 1, 23, 0, 0), 'IDTAB': u'ARE', 'Precalcolata': True,
                'Colonne': 3L, 'Ordine': 2L, 'ID': u'ARE', 'TitoloBreve': u'Aree Geogr.',
                'SeriesData': [35.6923, 35.6923, 14.6171, 13.8417, 0.7754, 26.1526, 2.3239, 0.1995, 3.7837, 9.3036, 0.9234, 1.3876, 8.2309],
                'SottoTitolo': u'Dati in % calcolati sul Nav del fondo. ', 'Righe': 0L,
                'Titolo': u'Aree Geografiche',
                'Categories': [
                    'AMERICA',
                    "--- STATI UNITI D'AMERICA              ",
                    'ASIA',
                    '--- GIAPPONE                           ',
                    '--- ALTRI',
                    'EUROPA',
                    '--- GERMANIA                           ',
                    '--- SPAGNA                             ',
                    '--- FRANCIA                            ',
                    '--- ITALIA                             ',
                    '--- PAESI BASSI                        ',
                    '--- REGNO UNITO                        ',
                    '--- ALTRI'
                ]
            }

        else:
            data = acomea_client.get_aree_geografiche(request.POST['codfondo'])

        fund = Fund.objects.get(code=request.POST['codfondo'])
        dst = None
        data_set = {}

        dsb = GRAPH_DATASET_BAR
        dsb['title']['text'] = data['line']['Titolo']
        dsb['subtitle']['text'] = data['line']['SottoTitolo']
        dsb['xAxis']['categories'] = data['line']['Categories']
        dsb['series'][0]['data'] = data['line']['SeriesData']
        dst =  data['line']['SeriesData']
        data_set['bar'] = json.dumps(dsb, default=json_util.default)

        dsp = GRAPH_DATASET_PIE
        dsp['title']['text'] = data['pie']['Titolo']
        dsp['subtitle']['text'] = data['pie']['SottoTitolo']
        dsp['xAxis']['categories'] = data['pie']['Categories']
        dsp['series'][0]['data'] = data['pie']['SeriesData']
        dst =  data['pie']['SeriesData']
        data_set['pie'] = json.dumps(dsp, default=json_util.default)

        data_set['fund'] = fund
        data_set['table'] = dst

    except Exception, e:
        log.error("Exc in get_aree_geografiche : %s" % str(e))
    return render_to_response('cms_plugins/_aree_geografiche.html',
        { 'data_set' : data_set }, RequestContext(request))

@csrf_exempt
def get_scadenza(request):
    try:
        if settings.VISTESOAP_FAKE_DATA:
            import datetime
            data = {
                'DataAggiornamento': datetime.datetime(2013, 1, 23, 0, 0), 'IDTAB': u'SCA', 'Precalcolata': True,
                'Colonne': 2L, 'Ordine': 5L, 'ID': u'SCA', 'TitoloBreve': u'Scadenza',
                'SeriesData': [36.007, 40.3735, 15.6812, 0.3631],
                'SottoTitolo': u'Dati in % calcolati sul Nav del fondo. (Obbligazioni)', 'Righe': 0L,
                'Titolo': u'Ripartizione del portafoglio per scadenza',
                'Categories': [
                    'minore uguale a 3 anni', 'maggiore di 3 anni e minore uguale di 5 anni',
                    'maggiore di 5 anni e minore uguale di 10 anni', 'maggiore di 10 anni'
                ]
            }

        else:
            data = acomea_client.get_scadenza(request.POST['codfondo'])

        fund = Fund.objects.get(code=request.POST['codfondo'])
        dst = None
        data_set = {}

        dsb = GRAPH_DATASET_BAR
        dsb['title']['text'] = data['line']['Titolo']
        dsb['subtitle']['text'] = data['line']['SottoTitolo']
        dsb['xAxis']['categories'] = data['line']['Categories']
        dsb['series'][0]['data'] = data['line']['SeriesData']
        data_set['bar'] = json.dumps(dsb, default=json_util.default)

        dsp = GRAPH_DATASET_PIE
        dsp['title']['text'] = data['pie']['Titolo']
        dsp['subtitle']['text'] = data['pie']['SottoTitolo']
        dsp['xAxis']['categories'] = data['pie']['Categories']
        dsp['series'][0]['data'] = data['pie']['SeriesData']
        dst = data['pie']['SeriesData']
        data_set['pie'] = json.dumps(dsp, default=json_util.default)

        data_set['fund'] = fund
        data_set['table'] = dst

    except Exception, e:
        log.error("Exc in get_scadenza : %s" % str(e))
    return render_to_response('cms_plugins/_scadenza.html',
        { 'data_set' : data_set }, RequestContext(request))


@csrf_exempt
def get_principali_paesi(request):
    try:
        if settings.VISTESOAP_FAKE_DATA:
            import datetime
            data = {
                'DataAggiornamento': datetime.datetime(2013, 1, 23, 0, 0), 'IDTAB': u'PPO', 'Precalcolata': True,
                'Colonne': 0L, 'Ordine': 3L, 'ID': u'PPI', 'TitoloBreve': u'Paesi',
                'SeriesData': [88.9083, 2.8915, 0.625],
                'SottoTitolo': u'Dati in % calcolati sul Nav del fondo. (Obbligazioni) ',
                'Righe': 10L, 'Titolo': u"Principali paesi d'Investimento",
                'Categories': [
                    'ITALIA                             ',
                    'PORTOGALLO                         ',
                    'SPAGNA                             '
                ]
            }
        else:
            data = acomea_client.get_principali_paesi(request.POST['codfondo'])

        fund = Fund.objects.get(code=request.POST['codfondo'])
        dst = None
        data_set = {}

        print "principali paesi:", data

        dsb = GRAPH_DATASET_BAR
        dsb['title']['text'] = data['line']['Titolo']
        dsb['subtitle']['text'] = data['line']['SottoTitolo']
        dsb['xAxis']['categories'] = data['line']['Categories']
        dsb['series'][0]['data'] = data['line']['SeriesData']
        data_set['bar'] = json.dumps(dsb, default=json_util.default)

        dsp = GRAPH_DATASET_PIE
        dsp['title']['text'] = data['pie']['Titolo']
        dsp['subtitle']['text'] = data['pie']['SottoTitolo']
        dsp['xAxis']['categories'] = data['pie']['Categories']
        dsp['series'][0]['data'] = data['pie']['SeriesData']
        dst =  data['pie']['SeriesData']
        data_set['pie'] = json.dumps(dsp, default=json_util.default)

        data_set['fund'] = fund
        data_set['table'] = dst

    except Exception, e:
        log.error("Exc in get_principali_paesi : %s" % str(e))
    return render_to_response('cms_plugins/_principali_paesi.html',
        { 'data_set' : data_set }, RequestContext(request))

@csrf_exempt
def get_valute(request):
    try:
        if settings.VISTESOAP_FAKE_DATA:
            import datetime
            data = {
                'DataAggiornamento': datetime.datetime(2013, 1, 23, 0, 0), 'IDTAB': u'RPV', 'Precalcolata': True,
                'Colonne': 3L, 'Ordine': 6L, 'ID': u'RPV', 'TitoloBreve': u'Valute',
                'SeriesData': [97.38, -3.74],
                'SottoTitolo': u'Principali valute, in % sul NAV del Fondo. ', 'Righe': 0L, 'Titolo': u'Valute',
                'Categories': ['EURO                     ', 'DOLLARO U.S.A.           ']
            }

        else:
            data = acomea_client.get_valute(request.POST['codfondo'])

        fund = Fund.objects.get(code=request.POST['codfondo'])
        dst = None
        data_set = {}

        print "valute:", data

        dsb = GRAPH_DATASET_BAR
        dsb['title']['text'] = data['line']['Titolo']
        dsb['subtitle']['text'] = data['line']['SottoTitolo']
        dsb['xAxis']['categories'] = data['line']['Categories']
        dsb['series'][0]['data'] = data['line']['SeriesData']
        dst =  data['line']['SeriesData']
        data_set['bar'] = json.dumps(dsb, default=json_util.default)

        dsp = GRAPH_DATASET_PIE
        dsp['title']['text'] = data['pie']['Titolo']
        dsp['subtitle']['text'] = data['pie']['SottoTitolo']
        dsp['xAxis']['categories'] = data['pie']['Categories']
        dsp['series'][0]['data'] = data['pie']['SeriesData']
        dst =  data['pie']['SeriesData']
        data_set['pie'] = json.dumps(dsp, default=json_util.default)

        data_set['fund'] = fund
        data_set['table'] = dst

    except Exception, e:
        log.error("Exc in get_valute : %s" % str(e))
    return render_to_response('cms_plugins/_valute.html',
        { 'data_set' : data_set }, RequestContext(request))

@csrf_exempt
def get_rating(request):
    try:
        if settings.VISTESOAP_FAKE_DATA:
            import datetime
            data = {
                'DataAggiornamento': datetime.datetime(2013, 1, 23, 0, 0), 'IDTAB': u'RAT', 'Precalcolata': True,
                'Colonne': 0L, 'Ordine': 2L, 'ID': u'RAT', 'TitoloBreve': u'Rating',
                'SeriesData': [54.8613, 5.4865, 32.9082, 6.5029, 0.2408],
                'SottoTitolo': u'Dati in % sul NAV della componente obbligazionaria del portafoglio. ', 'Righe': 0L,
                'Titolo': u'Rating', 'Categories': ['A', 'AA', 'BBB', 'NIG', 'nr', 'A']
            }

        else:
            data = acomea_client.get_rating(request.POST['codfondo'])

        fund = Fund.objects.get(code=request.POST['codfondo'])
        dst = None
        data_set = {}

        dsb = GRAPH_DATASET_BAR
        dsb['title']['text'] = data['line']['Titolo']
        dsb['subtitle']['text'] = data['line']['SottoTitolo']
        dsb['xAxis']['categories'] = data['line']['Categories']
        dsb['series'][0]['data'] = data['line']['SeriesData']
        data_set['bar'] = json.dumps(dsb, default=json_util.default)

        dsp = GRAPH_DATASET_PIE
        dsp['title']['text'] = data['pie']['Titolo']
        dsp['subtitle']['text'] = data['pie']['SottoTitolo']
        dsp['xAxis']['categories'] = data['pie']['Categories']
        dsp['series'][0]['data'] = data['pie']['SeriesData']
        dst =  data['pie']['SeriesData']
        data_set['pie'] = json.dumps(dsp, default=json_util.default)

        data_set['fund'] = fund
        data_set['table'] = dst

    except Exception, e:
        log.error("Exc in get_rating : %s" % str(e))
    return render_to_response('cms_plugins/_rating.html',
        { 'data_set' : data_set }, RequestContext(request))

@csrf_exempt
def get_titoli(request):
    data_set = {}
    try:
        if settings.VISTESOAP_FAKE_DATA:
            import datetime
            data = {
                'DataAggiornamento': datetime.datetime(2013, 1, 23, 0, 0), 'IDTAB': u'PTO', 'Precalcolata': True,
                'Colonne': 0L, 'Ordine': 7L, 'ID': u'PTP', 'TitoloBreve': u'Titoli',
                'SeriesData': [
                    18.2662, 17.5707, 11.4782, 7.3798, 5.3825, 5.071, 4.9741, 4.2766, 2.8915, 2.6451,
                    2.5432, 2.505, 2.2199, 1.3716, 1.2172, 0.8989, 0.66, 0.4844, 0.2258, 0.2225
                ],
                'SottoTitolo': u'Principali obbligazioni, in % sul NAV del Fondo. ', 'Righe': 20L,
                'Titolo': u'Titoli',
                'Categories': [
                    'BTP-IT 22/10/2016 IL 2,55', 'CCT 01/03/2017           ',
                    'CCT 01/09/2015           ', 'VICEN 27/02/2015 6,75%   ',
                    'MONTE 19/09/2014 4,875%  ', 'BTP 15/09/2021 2,1% I/L  ',
                    'PMIIM 29/06/2015 FLOAT   ', 'UNIIM 15/6/2021 FLOAT    ',
                    'PGB 15/06/2020 4,8%      ', 'MONTE 10/07/2015 7,25%   ',
                    'UCGIM 31/10/2022 6,95%   ', 'CCT 01/07/2016           ',
                    'VENBAN 12/11/14 FLOAT    ', 'BPIM 28/01/2016 3,75%    ',
                    'PMIIM 22/01/2016 4%      ', 'PMIIM 25/06/2049 VAR     ',
                    'BTP 15/09/2017 2,1 I/L   ', 'POPSM 16/09/2013 3,625%  ',
                    'PMIIM 31/01/2014 FLOAT   ', 'BK 30/12/2099 VAR        '
                ]
            }
        else:
            data = acomea_client.get_titoli(request.POST['codfondo'])

        fund = Fund.objects.get(code=request.POST['codfondo'])
        dst = None

        dsb = GRAPH_DATASET_BAR
        dsb['title']['text'] = data['line']['Titolo']
        dsb['subtitle']['text'] = data['line']['SottoTitolo']
        dsb['xAxis']['categories'] = data['line']['Categories']
        dsb['series'][0]['data'] = data['line']['SeriesData']
        data_set['bar'] = json.dumps(dsb, default=json_util.default)

        dsp = GRAPH_DATASET_PIE
        dsp['title']['text'] = data['pie']['Titolo']
        dsp['subtitle']['text'] = data['pie']['SottoTitolo']
        dsp['xAxis']['categories'] = data['pie']['Categories']
        dsp['series'][0]['data'] = data['pie']['SeriesData']
        dst =  data['pie']['SeriesData']
        data_set['pie'] = json.dumps(dsp, default=json_util.default)

        data_set['fund'] = fund
        data_set['table'] = dst

    except Exception, e:
        log.error("Exc in get_titoli : %s" % str(e))
    return render_to_response('cms_plugins/_titoli.html',
        { 'data_set' : data_set }, RequestContext(request))

@csrf_exempt
def get_classi_di_attivita(request):
    try:
        if settings.VISTESOAP_FAKE_DATA:
            import datetime
            data = {
                'DataAggiornamento': datetime.datetime(2013, 1, 23, 0, 0), 'IDTAB': u'CP3', 'Precalcolata': True,
                'Colonne': 0L, 'Ordine': 1L, 'ID': u'CP', 'TitoloBreve': u'Classi di attivit\xe0',
                'SeriesData': [5.3542, 58.5832, 0.993, 0.2225, 33.6191, 0.1654],
                'SottoTitolo': u'Dati in % calcolati sul Nav del fondo. ',
                'Righe': 0L, 'Titolo': u'Classi di attivit\xe0',
                'Categories': [
                    'Azioni/Warrants', 'Titoli di Stato', 'ETC', 'Obbl. Convertibili',
                    'Obbl. Soc. e Altri Emitt.', 'Liquidita'
                ]
            }
        else:
            data = acomea_client.get_classi_di_attivita(request.POST['codfondo'])

        fund = Fund.objects.get(code=request.POST['codfondo'])
        dst = None
        data_set = {}

        dsb = GRAPH_DATASET_BAR
        dsb['title']['text'] = data['line']['Titolo']
        dsb['subtitle']['text'] = data['line']['SottoTitolo']
        dsb['xAxis']['categories'] = data['line']['Categories']
        dsb['series'][0]['data'] = data['line']['SeriesData']
        dst =  data['line']['SeriesData']
        data_set['bar'] = json.dumps(dsb, default=json_util.default)

        dsp = GRAPH_DATASET_PIE
        dsp['title']['text'] = data['pie']['Titolo']
        dsp['subtitle']['text'] = data['pie']['SottoTitolo']
        dsp['xAxis']['categories'] = data['pie']['Categories']
        dsp['series'][0]['data'] = data['pie']['SeriesData']
        dst =  data['pie']['SeriesData']
        data_set['pie'] = json.dumps(dsp, default=json_util.default)

        data_set['fund'] = fund
        data_set['table'] = dst

    except Exception, e:
        log.error("Exc in get_classi_di_attivita : %s" % str(e))
    return render_to_response(
        'cms_plugins/_classi_di_attivita.html',
        { 'data_set' : data_set }, RequestContext(request)
    )

@csrf_exempt
def get_andamento(request):
    try:
        if settings.VISTESOAP_FAKE_DATA:
            import datetime
            data = {
                'HasBenchmark': True, 'Perf_COMP_Bench10Anni': 7.264543392464917,
                'BENCHID': 41L, 'TOTPORTIT': 18000112.86, 'NINDCEDOLA': 0L,
                'Perf_BT_Fondo1D': -0.615249395737216, 'BENCHCODE': u'FTS9ALWR',
                'NAV': 15557468.78, 'Perf_LT_Fondo1Anno': 13.1740272738646,
                'Perf_COMP_Fondo10Anni': 0.20910611880460284, 'Perf_LT_Bench5Anni': 16.013251647626415,
                'Perf_COMP_Bench3Anni': 8.255972040352777, 'PercIndice1': 100.0,
                'DTVALO': datetime.datetime(2013, 1, 24, 0, 0),
                'DESCRFON': u'ACOMEA GLOBALE CLASSE A1', 'dt1M': datetime.datetime(2012, 12, 21, 0, 0),
                'TOTATT': 17822812.02, 'Perf_BT_Fondo1M': 5.578898225957049,
                'Data_Avvio': datetime.datetime(2002, 12, 30, 0, 0), 'BENCHDESCR': u'FT/S&P ALL WORLD INDEX LC TR',
                'dt1G': datetime.datetime(2013, 1, 22, 0, 0), 'BENCHID_EU': 0L, 'QUOTA': 9.046,
                'Perf_BT_Bench1W': 1.1471135940409827, 'Perf_LT_Bench3Anni': 26.8690219433827, 'HASCEDOLA': False,
                'Perf_BT_Bench1M': 4.401645331180548, 'FonType': 1, 'dt1A': datetime.datetime(2012, 1, 23, 0, 0),
                'dt1W': datetime.datetime(2013, 1, 16, 0, 0), 'dt3A': datetime.datetime(2010, 1, 22, 0, 0),
                'Perf_BT_BenchYTD': 5.003093102381673, 'Perf_LT_BenchDalLancio': 101.15043544917314,
                'Perf_BT_Bench1D': 0.0, 'Perf_BT_Fondo1W': 1.33303461409209, 'BENCHDESCR_EU': u'0',
                'Data_Quota_MAX': datetime.datetime(2007, 6, 15, 0, 0), 'CODFON': u'GL', 'BENCHCODE_EU': u'0',
                'CodIndice2': None, 'dtIA': datetime.datetime(2012, 12, 28, 0, 0),
                'Perf_LT_Fondo10Anni': 2.11084772547692, 'Perf_BT_FondoYTD': 5.92505854800938,
                'dt10A': datetime.datetime(2003, 1, 23, 0, 0), 'Perf_LT_Fondo3Anni': 15.2944175375988,
                'TOTLIQ': 1597968.02, 'CodIndice1EU': None, 'TOTSOTT': 0.0, 'NAVGESTIONE': 0.0,
                'Perf_LT_FondoDalLancio': -0.165544641871762, 'PercIndice2': 0.0,
                'Perf_LT_Bench1Anno': 15.926068211892307, 'Perf_COMP_Bench5Anni': 3.0152497787856003,
                'DTINIZIOVALQUOTA': datetime.datetime(2002, 12, 30, 0, 0), 'Quota_MIN': 5.79,
                'Perf_COMP_Fondo5Anni': -1.1033526996760967, 'DecBenchDescr': u'FT/S&P ALL WORLD INDEX LC TR',
                'Quota_MAX': 11.829, 'CLASSE': u'A1', 'Perf_LT_Fondo5Anni': -5.396360594017991,
                'Data_Quota_MIN': datetime.datetime(2009, 3, 9, 0, 0), 'Perf_COMP_Fondo3Anni': 4.858287293642394,
                'TOTRIMB': 0.0, 'DTGIRO': datetime.datetime(2013, 1, 23, 0, 0), 'Perf_LT_Bench10Anni': 101.633126272329,
                'dtfine': datetime.datetime(2013, 1, 23, 0, 0), 'Quota_Avvio': 9.061, 'TOTVALO': 0.0,
                'dt5A': datetime.datetime(2008, 1, 23, 0, 0), 'CodIndice1': u'FTS9ALWR'
            }
        else:
            data = acomea_client.get_andamento(request.POST['codfondo'], request.POST['classe'])
    except Exception, e:
        log.error("Exc in get_andamento : %s" % str(e))
    return render_to_response('cms_plugins/_andamento.html',
        { 'data_set' : data }, RequestContext(request))

@csrf_exempt
def get_serie_storica(request):
    try:
        data = acomea_client.get_serie_storica(request.POST['codfondo'], request.POST['classe'])
    except Exception, e:
        log.error("Exc in get_serie_storica : %s" % str(e))
    return render_to_response('cms_plugins/_serie_storica.html',
        { 'data_set' : data }, RequestContext(request))

@csrf_exempt
def get_rendimenti_annui(request):
    try:
        data = acomea_client.get_rendimenti_annui(request.POST['codfondo'], request.POST['classe'])
    except Exception, e:
        log.error("Exc in get_rendimenti_annui : %s" % str(e))
    return render_to_response(
        'cms_plugins/_rendimenti_annui.html',
        { 'data_set' : data }, RequestContext(request)
    )

@csrf_exempt
def get_grafico(request):
    try:
        raw_data = acomea_client.get_grafico(request.POST['codfondo'], request.POST['classe'])
        dsl = GRAPH_DATASET_LINE
        dsl['title']['text'] = raw_data['Sottotitolo']
        serie_fondo = {
            'name': 'fondo',
            'data' : [],
            'color': '#F15A22'
        }
        for l in raw_data['SeriesData']:
            datepy = datetime.date(int(l['data'][0:4]), int(l['data'][5:7]), int(l['data'][8:10]))
            dateutc = "Date.UTC(%s, %s, %s)" % (datepy.year, datepy.month, datepy.day)
            serie_fondo['data'].append((dateutc, float(l['valf'])))
        dsl['series'].append(serie_fondo)
        data_set = {}
        data_set['line'] = json.dumps(dsl, default=json_util.default)
    except Exception, e:
        log.error("Exc in get_grafico : %s" % str(e))
    return render_to_response('cms_plugins/_grafico.html',
    { 'data_set' : data_set }, RequestContext(request))

def check_cliente(request):
    data = acomea_client.check_cliente(cod_fiscale=request.POST['cod-fiscale'])
    return HttpResponse("ok")

def get_cliente(request):
    data = acomea_client.check_cliente(cod_fiscale=request.POST['cod-fiscale'])
    return HttpResponse("ok")
